@@ -74,6 +74,17 @@ class Bridge(BridgeBase):
     def bluetooth(self) -> Bluetooth:
         return self._bluetooth
 
+    @property
+    def configuration_url(self) -> str:
+        """Get configuration url"""
+        url = f"{self.base_url}/app/settings?apiKey={self._api_key}"
+        if self.information is not None:
+            if self.information.apiPort is not None:
+                url += f"&apiPort={self.information.apiPort}"
+            if self.information.websocketPort is not None:
+                url += f"&wsPort={self.information.websocketPort}"
+        return url
+
     @property
     def cpu(self) -> Cpu:
         return self._cpu
